@@ -1,7 +1,7 @@
 import statistics
 from copy import deepcopy
 
-from wxkit.services import WeatherService
+from wxkit.services import WxService
 from wxkit.models import ErrorModel, Wind, Temperature, Station, WeatherPoint
 from wxkit.utils.http_request import retry_request, compose_url_path, HTTP_METHOD
 
@@ -31,7 +31,7 @@ def strip_data(obj):
     return obj
 
 
-class OpenWeatherService(WeatherService):
+class OpenweatherWxService(WxService):
     def __init__(self, credential):
         super().__init__(credential)
         self._params = dict(appid=self.credential.appid, units="metric")
